==> polls-v1.4.1.zip: polls/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Merk:</strong> Resultatene er skjult til meningsmålingen avsluttes av moderator.',
    'Access denied!' => 'Ingen tilgang!',
    'Add answer...' => 'Legg til svar...',
    'Again? ;Weary;' => 'Igjen? ; Weary',
    'Allows the user to create polls' => 'Tillat bruker å lage avstemming',
    'Allows to start polls.' => 'Tillater å starte en avstemming.',
    'Anonymous' => 'Anonym',
    'Anonymous Votes?' => 'Anonyme svar?',
    'Anonymous poll!' => 'Anonym avstemming',
    'Answers' => 'Svar',
    'At least one answer is required' => 'Minst et svar er påkrevd',
    'Cancel' => 'Avbryt',
    'Close Poll' => 'Ferdigstill avstemming',
    'Closed' => 'Lukket',
    'Club A Steakhouse' => 'Bestem et sted å møtes',
    'Could not load poll!' => 'Kunne ikke laste avstemming!',
    'Create poll' => 'Lag avstemming',
    'Description' => 'Beskrivelse',
    'Display answers in random order?' => 'Vis svar i tilfeldig rekkefølge?',
    'Edit answer (empty answers will be removed)...' => 'Rediger svar (tomme svar vil fjernes)...',
    'Edit your poll question...' => 'Rediger spørsmålet...',
    'Hide results until poll is closed?' => 'Ikke vis resultat før avstemming er avsluttet?',
    'Invalid answer!' => 'Ugyldig svar!',
    'Location of the next meeting' => 'Sted for neste møte',
    'Multiple answers per user' => 'Flere svar pr bruker',
    'Pisillo Italian Panini' => 'på hjørnet',
    'Please specify at least {min} answers!' => 'Vennligst spesifisér minst {min} svaralternativer!',
    'Poll' => 'Spørsmål',
    'Polls' => 'Avstemminger',
    'Question' => 'Spørsmål',
    'Reopen Poll' => 'Gjenåpne avstemminger',
    'Reset my vote' => 'Tilbakestill min stemme',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Akkurat nå er vi i planleggingen av neste møte, vi ønsker å vite hvor vi skal møtes?',
    'Save' => 'Lagre',
    'To Daniel' => 'Hos Daniel',
    'Users voted for: <strong>{answer}</strong>' => 'Brukerne stemte for: <strong>{answer}</strong>',
    'Vote' => 'Stem',
    'Voting for multiple answers is disabled!' => 'Stemming på flere alternativer er ikke tillatt!',
    'Whenever someone participates in a poll.' => 'Når noen stemmer i en avstemming',
    'Why don\'t we go to Bemelmans Bar?' => 'Hva med nærmeste bar?',
    'You have insufficient permissions to perform that operation!' => 'Du har ikke tilgang til å utføre handlingen!',
    'and {count} more vote for this.' => 'og {count} stemte på dette.',
    'votes' => 'stemmer',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} svarte på {question}.',
    'Poll content ID' => '',
];

==> polls-v1.4.2.zip: polls/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Merk:</strong> Resultatene er skjult til meningsmålingen avsluttes av moderator.',
    'Access denied!' => 'Ingen tilgang!',
    'Add answer...' => 'Legg til svar...',
    'Again? :weary:' => 'Igjen? ; Weary',
    'Allows the user to create polls' => 'Tillat bruker å lage avstemming',
    'Allows to start polls.' => 'Tillater å starte en avstemming.',
    'Anonymous' => 'Anonym',
    'Anonymous Votes?' => 'Anonyme svar?',
    'Anonymous poll!' => 'Anonym avstemming',
    'Answers' => 'Svar',
    'At least one answer is required' => 'Minst et svar er påkrevd',
    'Cancel' => 'Avbryt',
    'Close Poll' => 'Ferdigstill avstemming',
    'Closed' => 'Lukket',
    'Club A Steakhouse' => 'Bestem et sted å møtes',
    'Could not load poll!' => 'Kunne ikke laste avstemming!',
    'Create poll' => 'Lag avstemming',
    'Description' => 'Beskrivelse',
    'Display answers in random order?' => 'Vis svar i tilfeldig rekkefølge?',
    'Edit answer (empty answers will be removed)...' => 'Rediger svar (tomme svar vil fjernes)...',
    'Edit your poll question...' => 'Rediger spørsmålet...',
    'Hide results until poll is closed?' => 'Ikke vis resultat før avstemming er avsluttet?',
    'Invalid answer!' => 'Ugyldig svar!',
    'Location of the next meeting' => 'Sted for neste møte',
    'Multiple answers per user' => 'Flere svar pr bruker',
    'Pisillo Italian Panini' => 'på hjørnet',
    'Please specify at least {min} answers!' => 'Vennligst spesifisér minst {min} svaralternativer!',
    'Poll' => 'Spørsmål',
    'Polls' => 'Avstemminger',
    'Question' => 'Spørsmål',
    'Reopen Poll' => 'Gjenåpne avstemminger',
    'Reset my vote' => 'Tilbakestill min stemme',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Akkurat nå er vi i planleggingen av neste møte, vi ønsker å vite hvor vi skal møtes?',
    'Save' => 'Lagre',
    'To Daniel' => 'Hos Daniel',
    'Users voted for: <strong>{answer}</strong>' => 'Brukerne stemte for: <strong>{answer}</strong>',
    'Vote' => 'Stem',
    'Voting for multiple answers is disabled!' => 'Stemming på flere alternativer er ikke tillatt!',
    'Whenever someone participates in a poll.' => 'Når noen stemmer i en avstemming',
    'Why don\'t we go to Bemelmans Bar?' => 'Hva med nærmeste bar?',
    'You have insufficient permissions to perform that operation!' => 'Du har ikke tilgang til å utføre handlingen!',
    'and {count} more vote for this.' => 'og {count} stemte på dette.',
    'votes' => 'stemmer',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} svarte på {question}.',
    'Poll content ID' => '',
];
